cpdef object read_bool(
    bytes binary_data,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef bytes write_bool(
    object dtype_value,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef unsigned long read_oid(
    bytes binary_data,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef bytes write_oid(
    object dtype_value,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef unsigned short read_serial2(
    bytes binary_data,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef bytes write_serial2(
    object dtype_value,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef unsigned long read_serial4(
    bytes binary_data,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef bytes write_serial4(
    object dtype_value,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef unsigned long long read_serial8(
    bytes binary_data,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef bytes write_serial8(
    object dtype_value,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef short read_int2(
    bytes binary_data,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef bytes write_int2(
    object dtype_value,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef long read_int4(
    bytes binary_data,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef bytes write_int4(
    object dtype_value,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef long long read_int8(
    bytes binary_data,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef bytes write_int8(
    object dtype_value,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef double read_money(
    bytes binary_data,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef bytes write_money(
    object dtype_value,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef float read_float4(
    bytes binary_data,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef bytes write_float4(
    object dtype_value,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef double read_float8(
    bytes binary_data,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef bytes write_float8(
    object dtype_value,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef object read_numeric(
    bytes binary_data,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
cpdef bytes write_numeric(
    object dtype_value,
    object pgoid_function=*,
    object buffer_object=*,
    object pgoid=*,
)
